@@ -2,20 +2,25 @@
 #'
 #' @param domain domain from which to download robots.txt file
 #' @param warn warn about being unable to download domain/robots.txt because of
-#' @param force if TRUE instead of using possible cached results the function will
-#'              re-download the robotstxt file
-#'              HTTP response status 404. If this happens,
-#' @param user_agent HTTP user-agent string to be used to retrieve robots.txt file
-#'   from domain
+#' @param force if TRUE instead of using possible cached results the function
+#'   will re-download the robotstxt file HTTP response status 404. If this
+#'   happens,
+#' @param user_agent HTTP user-agent string to be used to retrieve robots.txt
+#'   file from domain
+#'
+#' @param ssl_verifypeer analog to CURL option
+#'   \url{https://curl.haxx.se/libcurl/c/CURLOPT_SSL_VERIFYPEER.html} -- and
+#'   might help with robots.txt file retrieval in some cases
 #'
 #' @export
 
 get_robotstxt <-
   function(
     domain,
-    warn       = TRUE,
-    force      = FALSE,
-    user_agent = NULL
+    warn           = TRUE,
+    force          = FALSE,
+    user_agent     = utils::sessionInfo()$R.version$version.string,
+    ssl_verifypeer = c(1,0)
   ){
 
     # pre checking input
@@ -28,8 +33,9 @@ get_robotstxt <-
 
       request <-
         get_robotstxt_http_get(
-          domain     = domain,
-          user_agent = user_agent
+          domain         = domain,
+          user_agent     = user_agent,
+          ssl_verifypeer = ssl_verifypeer[1]
         )
 
     }else if ( !is.null(rt_cache[[domain]]) ) {
@@ -41,8 +47,9 @@ get_robotstxt <-
 
       request <-
         get_robotstxt_http_get(
-          domain     = domain,
-          user_agent = user_agent
+          domain         = domain,
+          user_agent     = user_agent,
+          ssl_verifypeer = ssl_verifypeer[1]
         )
 
     }
@@ -55,13 +62,6 @@ get_robotstxt <-
       if ( is_valid_robotstxt(rtxt) ){
         rt_cache[[domain]] <- request
       }else{
-        # give back a digest of the retrieved file
-        message(
-          "\n\n",
-          substring(paste(rtxt, collapse = "\n"), 1, 200),
-          "\n\n"
-        )
-
         # dump file
         fname_tmp <-
           tempfile(pattern = "robots_", fileext = ".txt")
@@ -72,14 +72,25 @@ get_robotstxt <-
           useBytes = TRUE
         )
 
-        # stop
-        stop(
-          paste(
-            "get_robotstxt(): the thing retrieved does not seem to be a valid robots.txt.",
-            "file dumpend to:",
-            fname_tmp
+        # give back a digest of the retrieved file
+        if( warn ){
+          message(
+            "\n\n",
+            "[domain] ", domain, " --> ", fname_tmp,
+            "\n\n",
+            substring(paste(rtxt, collapse = "\n"), 1, 200),"\n", "[...]",
+            "\n\n"
           )
-        )
+        }
+
+
+        # found file but could not parse it - can happen, everything is allowed
+        # --> treated as if there was no file
+          warning(paste0(
+            "get_robotstxt(): ",  domain, "; Not valid robots.txt."
+          ))
+        rtxt <- ""
+        rt_cache[[domain]] <- request
       }
     }
 
@@ -87,9 +98,7 @@ get_robotstxt <-
     if( request$status == 404 ){
       if(warn){
         warning(paste0(
-          "get_robotstxt(): could not get robots.txt from domain: ",
-          domain,
-          " HTTP status: 404"
+          "get_robotstxt(): ",  domain, "; HTTP status: ",  request$status
         ))
       }
       rtxt <- ""
@@ -99,10 +108,7 @@ get_robotstxt <-
     # not ok - diverse
     if( !(request$status == 404 | request$status < 400) ){
       stop(paste0(
-        "get_robotstxt(): could not get robots.txt from domain: ",
-        domain,
-        "; HTTP status: ",
-        request$status
+        "get_robotstxt(): ",  domain, "; HTTP status: ",  request$status
       ))
     }
     # return
